You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by jb...@apache.org on 2006/12/23 16:47:57 UTC

svn commit: r489901 - in /incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment: AssemblyService.java ContributionService.java Deployer.java

Author: jboynes
Date: Sat Dec 23 07:47:56 2006
New Revision: 489901

URL: http://svn.apache.org/viewvc?view=rev&rev=489901
Log:
split deployment into contribution and assembly services

Added:
    incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java   (with props)
    incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/ContributionService.java   (contents, props changed)
      - copied, changed from r489443, incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/Deployer.java
Removed:
    incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/Deployer.java

Added: incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java?view=auto&rev=489901
==============================================================================
--- incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java (added)
+++ incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java Sat Dec 23 07:47:56 2006
@@ -0,0 +1,49 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ * 
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.    
+ */
+package org.apache.tuscany.host.deployment;
+
+import java.io.IOException;
+import java.io.InputStream;
+import java.net.URL;
+
+/**
+ * Service interface for managing the logical assembly for a Tuscany runtime.
+ *
+ * @version $Rev$ $Date$
+ */
+public interface AssemblyService {
+    /**
+     * Apply a set of changes to the SCA Domain's logical assembly.
+     *
+     * @param changeSet the location of a resource containing a set of changes
+     * @throws DeploymentException if there was a problem making the changes
+     * @throws IOException         if there was a problem accessing the resource
+     */
+    void applyChanges(URL changeSet) throws DeploymentException, IOException;
+
+    /**
+     * Apply a set of changes to the SCA Domain's logical assembly.
+     *
+     * @param changeSet a stream for reading a resource containing a set of changes; the stream will not be closed
+     *                  but no guarantee is made on the position the stream is left in
+     * @throws DeploymentException if there was a problem making the changes
+     * @throws IOException         if there was a problem reading the stream
+     */
+    void applyChanges(InputStream changeSet) throws DeploymentException, IOException;
+}

Propchange: incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/AssemblyService.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Copied: incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/ContributionService.java (from r489443, incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/Deployer.java)
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/ContributionService.java?view=diff&rev=489901&p1=incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/Deployer.java&r1=489443&p2=incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/ContributionService.java&r2=489901
==============================================================================
--- incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/Deployer.java (original)
+++ incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/ContributionService.java Sat Dec 23 07:47:56 2006
@@ -24,11 +24,11 @@
 import java.net.URL;
 
 /**
  * Interface that allows artifacts to be deployed to a Tuscany runtime.
  *
  * @version $Rev$ $Date$
  */
-public interface Deployer {
+public interface ContributionService {
     /**
      * Contribute an artifact to the SCA Domain.
      * The type of the contribution is determined by the Content-Type of the resource

Propchange: incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/ContributionService.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/java/sca/kernel/host-api/src/main/java/org/apache/tuscany/host/deployment/ContributionService.java
------------------------------------------------------------------------------
    svn:keywords = Rev Date



---------------------------------------------------------------------
@@ -24,11 +24,11 @@
 
 /**
- * Interface that allows artifacts to be deployed to a Tuscany runtime.
+ * Service interface that manages artifacts contributed to a Tuscany runtime.
  *
  * @version $Rev$ $Date$
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org